@@ -5,6 +5,11 @@ class WorkerConstant(object):
     # worker 运行模式
     RUN_MODE_THREAD = "thread"
     RUN_MODE_PROCESS = "process"
+    RUN_MODE_COROUTINE = "coroutine"
+    # worker 运行模式（缩写）
+    RUN_MODE_THREAD_ABBREVIATE = "T"
+    RUN_MODE_PROCESS_ABBREVIATE = "P"
+    RUN_MODE_COROUTINE_ABBREVIATE = "C"
     
     # 运行策略
     RUN_POLICY_SAFE = "safe"
